Learn R Programming

DESeq2 (version 1.6.3)

dispersionFunction: Accessors for the 'dispersionFunction' slot of a DESeqDataSet object.

Description

The dispersion function is calculated by estimateDispersions and used by varianceStabilizingTransformation. Parametric dispersion fits store the coefficients of the fit as attributes in this slot.

Usage

dispersionFunction(object, ...)
dispersionFunction(object, ...) <- value
"dispersionFunction"(object)
"dispersionFunction"(object,estimateVar)<-value
"dispersionFunction"(object)

Arguments

object
a DESeqDataSet object.
...
additional arguments
value
a function
estimateVar
whether to estimate the variance of dispersion residuals. setting to FALSE is needed, e.g. within estimateDispersionsMAP when called on a subset of the full dataset in parallel execution.

Examples

Run this code
example("estimateDispersions")
dispersionFunction(dds)

Run the code above in your browser using DataLab