Learn R Programming

DESeq2 (version 1.6.3)

dispersions: Accessor functions for the dispersion estimates in a DESeqDataSet object.

Description

The dispersions for each row of the DESeqDataSet. Generally, these should be set only by estimateDispersions.

Usage

dispersions(object, ...)
dispersions(object, ...) <- value
"dispersions"(object)
"dispersions"(object)<-value
"dispersions"(object)

Arguments

object
a DESeqDataSet object.
...
additional arguments
value
the dispersions to use for the Negative Binomial modeling

See Also

estimateDispersions

Examples

Run this code
example("estimateDispersions")
head(dispersions(dds))

Run the code above in your browser using DataLab