sizeFactors: Accessor functions for the 'sizeFactors' information in a DESeqDataSet
object.
Description
The sizeFactors vector assigns to each column of the count matrix a value, the
size factor, such that count values in the columns can be brought to a common
scale by dividing by the corresponding size factor. See DESeq
for a description of the use of size factors. If gene-specific normalization
is desired for each sample, use normalizationFactors.
Usage
"sizeFactors"(object)
"sizeFactors"(object)<-value
"sizeFactors"(object)
"sizeFactors"(object) <- value
Arguments
object
a DESeqDataSet object.
value
a numeric vector, one size factor for each column in the count
data.