counts: Accessors for the 'counts' slot of a DESeqDataSet object.
Description
The counts slot holds the count data as a matrix of non-negative integer
count values, one row for each observational unit (gene or the like), and one
column for each sample.
Usage
"counts"(object,normalized=FALSE)
"counts"(object)<-value
"counts"(object, normalized = FALSE)
"counts"(object) <- value
Arguments
object
a DESeqDataSet object.
normalized
logical indicating whether or not to divide the counts by
the size factors or normalization factors before returning
(normalization factors always preempt size factors)